==> cobalt-0.0.1-sources.jar: it/auties/whatsapp/model/info/ExternalAdReplyInfoBuilder.java <==
package it.auties.whatsapp.model.info;

public class ExternalAdReplyInfoBuilder {
    private java.util.Optional<java.lang.String> title;
    private java.util.Optional<java.lang.String> body;
    private java.util.Optional<it.auties.whatsapp.model.info.ExternalAdReplyInfo.MediaType> mediaType;
    private java.util.Optional<java.lang.String> thumbnailUrl;
    private java.util.Optional<java.lang.String> mediaUrl;
    private java.util.Optional<byte[]> thumbnail;
    private java.util.Optional<java.lang.String> sourceType;
    private java.util.Optional<java.lang.String> sourceId;
    private java.util.Optional<java.lang.String> sourceUrl;
    private boolean containsAutoReply;
    private boolean renderLargerThumbnail;
    private boolean showAdAttribution;
    private java.util.Optional<java.lang.String> ctwaClid;

    public ExternalAdReplyInfoBuilder() {
        title = java.util.Optional.empty();
        body = java.util.Optional.empty();
        mediaType = java.util.Optional.empty();
        thumbnailUrl = java.util.Optional.empty();
        mediaUrl = java.util.Optional.empty();
        thumbnail = java.util.Optional.empty();
        sourceType = java.util.Optional.empty();
        sourceId = java.util.Optional.empty();
        sourceUrl = java.util.Optional.empty();
        containsAutoReply = false;
        renderLargerThumbnail = false;
        showAdAttribution = false;
        ctwaClid = java.util.Optional.empty();
    }

    public ExternalAdReplyInfoBuilder title(java.util.Optional<java.lang.String> title) {
        this.title = title;
        return this;
    }
    public ExternalAdReplyInfoBuilder title(java.lang.String title) {
        this.title = java.util.Optional.ofNullable(title);
        return this;
    }
    public ExternalAdReplyInfoBuilder body(java.util.Optional<java.lang.String> body) {
        this.body = body;
        return this;
    }
    public ExternalAdReplyInfoBuilder body(java.lang.String body) {
        this.body = java.util.Optional.ofNullable(body);
        return this;
    }
    public ExternalAdReplyInfoBuilder mediaType(java.util.Optional<it.auties.whatsapp.model.info.ExternalAdReplyInfo.MediaType> mediaType) {
        this.mediaType = mediaType;
        return this;
    }
    public ExternalAdReplyInfoBuilder mediaType(it.auties.whatsapp.model.info.ExternalAdReplyInfo.MediaType mediaType) {
        this.mediaType = java.util.Optional.ofNullable(mediaType);
        return this;
    }
    public ExternalAdReplyInfoBuilder thumbnailUrl(java.util.Optional<java.lang.String> thumbnailUrl) {
        this.thumbnailUrl = thumbnailUrl;
        return this;
    }
    public ExternalAdReplyInfoBuilder thumbnailUrl(java.lang.String thumbnailUrl) {
        this.thumbnailUrl = java.util.Optional.ofNullable(thumbnailUrl);
        return this;
    }
    public ExternalAdReplyInfoBuilder mediaUrl(java.util.Optional<java.lang.String> mediaUrl) {
        this.mediaUrl = mediaUrl;
        return this;
    }
    public ExternalAdReplyInfoBuilder mediaUrl(java.lang.String mediaUrl) {
        this.mediaUrl = java.util.Optional.ofNullable(mediaUrl);
        return this;
    }
    public ExternalAdReplyInfoBuilder thumbnail(java.util.Optional<byte[]> thumbnail) {
        this.thumbnail = thumbnail;
        return this;
    }
    public ExternalAdReplyInfoBuilder thumbnail(byte[] thumbnail) {
        this.thumbnail = java.util.Optional.ofNullable(thumbnail);
        return this;
    }
    public ExternalAdReplyInfoBuilder sourceType(java.util.Optional<java.lang.String> sourceType) {
        this.sourceType = sourceType;
        return this;
    }
    public ExternalAdReplyInfoBuilder sourceType(java.lang.String sourceType) {
        this.sourceType = java.util.Optional.ofNullable(sourceType);
        return this;
    }
    public ExternalAdReplyInfoBuilder sourceId(java.util.Optional<java.lang.String> sourceId) {
        this.sourceId = sourceId;
        return this;
    }
    public ExternalAdReplyInfoBuilder sourceId(java.lang.String sourceId) {
        this.sourceId = java.util.Optional.ofNullable(sourceId);
        return this;
    }
    public ExternalAdReplyInfoBuilder sourceUrl(java.util.Optional<java.lang.String> sourceUrl) {
        this.sourceUrl = sourceUrl;
        return this;
    }
    public ExternalAdReplyInfoBuilder sourceUrl(java.lang.String sourceUrl) {
        this.sourceUrl = java.util.Optional.ofNullable(sourceUrl);
        return this;
    }
    public ExternalAdReplyInfoBuilder containsAutoReply(boolean containsAutoReply) {
        this.containsAutoReply = containsAutoReply;
        return this;
    }
    public ExternalAdReplyInfoBuilder renderLargerThumbnail(boolean renderLargerThumbnail) {
        this.renderLargerThumbnail = renderLargerThumbnail;
        return this;
    }
    public ExternalAdReplyInfoBuilder showAdAttribution(boolean showAdAttribution) {
        this.showAdAttribution = showAdAttribution;
        return this;
    }
    public ExternalAdReplyInfoBuilder ctwaClid(java.util.Optional<java.lang.String> ctwaClid) {
        this.ctwaClid = ctwaClid;
        return this;
    }
    public ExternalAdReplyInfoBuilder ctwaClid(java.lang.String ctwaClid) {
        this.ctwaClid = java.util.Optional.ofNullable(ctwaClid);
        return this;
    }

    public it.auties.whatsapp.model.info.ExternalAdReplyInfo build() {
        return new it.auties.whatsapp.model.info.ExternalAdReplyInfo(title, body, mediaType, thumbnailUrl, mediaUrl, thumbnail, sourceType, sourceId, sourceUrl, containsAutoReply, renderLargerThumbnail, showAdAttribution, ctwaClid);
    }
}

==> cobalt-0.0.7-sources.jar: it/auties/whatsapp/model/info/ExternalAdReplyInfoBuilder.java <==
package it.auties.whatsapp.model.info;

public class ExternalAdReplyInfoBuilder {
    private java.util.Optional<java.lang.String> title;
    private java.util.Optional<java.lang.String> body;
    private java.util.Optional<it.auties.whatsapp.model.info.ExternalAdReplyInfo.MediaType> mediaType;
    private java.util.Optional<java.lang.String> thumbnailUrl;
    private java.util.Optional<java.lang.String> mediaUrl;
    private java.util.Optional<byte[]> thumbnail;
    private java.util.Optional<java.lang.String> sourceType;
    private java.util.Optional<java.lang.String> sourceId;
    private java.util.Optional<java.lang.String> sourceUrl;
    private boolean containsAutoReply;
    private boolean renderLargerThumbnail;
    private boolean showAdAttribution;
    private java.util.Optional<java.lang.String> ctwaClid;

    public ExternalAdReplyInfoBuilder() {
        title = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
        body = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
        mediaType = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
        thumbnailUrl = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
        mediaUrl = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
        thumbnail = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
        sourceType = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
        sourceId = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
        sourceUrl = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
        containsAutoReply = false;
        renderLargerThumbnail = false;
        showAdAttribution = false;
        ctwaClid = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
    }

    public ExternalAdReplyInfoBuilder title(java.lang.String title) {
        this.title = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(title);
        return this;
    }

    public ExternalAdReplyInfoBuilder body(java.lang.String body) {
        this.body = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(body);
        return this;
    }

    public ExternalAdReplyInfoBuilder mediaType(it.auties.whatsapp.model.info.ExternalAdReplyInfo.MediaType mediaType) {
        this.mediaType = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(mediaType);
        return this;
    }

    public ExternalAdReplyInfoBuilder thumbnailUrl(java.lang.String thumbnailUrl) {
        this.thumbnailUrl = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(thumbnailUrl);
        return this;
    }

    public ExternalAdReplyInfoBuilder mediaUrl(java.lang.String mediaUrl) {
        this.mediaUrl = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(mediaUrl);
        return this;
    }

    public ExternalAdReplyInfoBuilder thumbnail(byte[] thumbnail) {
        this.thumbnail = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(thumbnail);
        return this;
    }

    public ExternalAdReplyInfoBuilder sourceType(java.lang.String sourceType) {
        this.sourceType = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(sourceType);
        return this;
    }

    public ExternalAdReplyInfoBuilder sourceId(java.lang.String sourceId) {
        this.sourceId = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(sourceId);
        return this;
    }

    public ExternalAdReplyInfoBuilder sourceUrl(java.lang.String sourceUrl) {
        this.sourceUrl = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(sourceUrl);
        return this;
    }

    public ExternalAdReplyInfoBuilder containsAutoReply(boolean containsAutoReply) {
        this.containsAutoReply = containsAutoReply;
        return this;
    }

    public ExternalAdReplyInfoBuilder renderLargerThumbnail(boolean renderLargerThumbnail) {
        this.renderLargerThumbnail = renderLargerThumbnail;
        return this;
    }

    public ExternalAdReplyInfoBuilder showAdAttribution(boolean showAdAttribution) {
        this.showAdAttribution = showAdAttribution;
        return this;
    }

    public ExternalAdReplyInfoBuilder ctwaClid(java.lang.String ctwaClid) {
        this.ctwaClid = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(ctwaClid);
        return this;
    }

    public it.auties.whatsapp.model.info.ExternalAdReplyInfo build() {
        return new it.auties.whatsapp.model.info.ExternalAdReplyInfo(title, body, mediaType, thumbnailUrl, mediaUrl, thumbnail, sourceType, sourceId, sourceUrl, containsAutoReply, renderLargerThumbnail, showAdAttribution, ctwaClid);
    }

}
